@@ -8,13 +8,14 @@ usage = ""
 min_args = 0
 colors = {}
 
+
 def color(vendor):
     global colors
 
     if vendor not in colors:
         r, g, b = np.random.randint(100, 255, 3)
         colors[vendor] = "#%02X%02X%02X" % (r, g, b)
-        
+
     return colors[vendor]
 
 
@@ -22,21 +23,21 @@ def run(args):
     graph = "digraph {\n"
 
     for directory in git.get_directories():
-        parts = directory.split('/')
+        parts = directory.split("/")
         vendor = parts[-2]
-        project_name = '/'.join(parts[-2:])
-        graph += "\"%s\" [style=filled, color=\"%s\"];\n" % (project_name, color(vendor))
+        project_name = "/".join(parts[-2:])
+        graph += '"%s" [style=filled, color="%s"];\n' % (project_name, color(vendor))
 
         config = env.get_config(directory)
-        if config and 'deps' in config:
-            for dep in config['deps']:
+        if config and "deps" in config:
+            for dep in config["deps"]:
                 infos = git.parse_repository_name(dep)
-                dep_name = "%s/%s" % (infos['vendor'], infos['name'])
-                graph += "\"%s\" -> \"%s\";\n" % (project_name, dep_name)
+                dep_name = "%s/%s" % (infos["vendor"], infos["name"])
+                graph += '"%s" -> "%s";\n' % (project_name, dep_name)
 
     graph += "}\n"
 
-    f = open('/tmp/deps.dot', 'w')
+    f = open("/tmp/deps.dot", "w")
     f.write(graph)
     f.close()
 
